# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CreateBrowserRequest(BaseModel):
    """
    CreateBrowserRequest
    """ # noqa: E501
    uc: Optional[StrictBool] = Field(default=True, description="uc")
    proxy: Optional[StrictStr] = Field(default=None, description="proxy")
    window_size: Optional[List[StrictInt]] = Field(default=None, description="window_size")
    user_agent: Optional[StrictStr] = Field(default=None, description="user_agent")
    disable_gpu: Optional[StrictBool] = Field(default=False, description="disable_gpu")
    disable_images: Optional[StrictBool] = Field(default=False, description="disable_images")
    disable_javascript: Optional[StrictBool] = Field(default=False, description="disable_javascript")
    extensions: Optional[List[StrictStr]] = Field(default=None, description="extensions")
    custom_args: Optional[List[StrictStr]] = Field(default=None, description="custom_args")
    profile_name: Optional[StrictStr] = Field(default=None, description="profile_name")
    __properties: ClassVar[List[str]] = ["uc", "proxy", "window_size", "user_agent", "disable_gpu", "disable_images", "disable_javascript", "extensions", "custom_args", "profile_name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateBrowserRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateBrowserRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "uc": obj.get("uc") if obj.get("uc") is not None else True,
            "proxy": obj.get("proxy"),
            "window_size": obj.get("window_size"),
            "user_agent": obj.get("user_agent"),
            "disable_gpu": obj.get("disable_gpu") if obj.get("disable_gpu") is not None else False,
            "disable_images": obj.get("disable_images") if obj.get("disable_images") is not None else False,
            "disable_javascript": obj.get("disable_javascript") if obj.get("disable_javascript") is not None else False,
            "extensions": obj.get("extensions"),
            "custom_args": obj.get("custom_args"),
            "profile_name": obj.get("profile_name")
        })
        return _obj


