# coding: utf-8

# flake8: noqa
"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from airbrowser_client.models.base_response import BaseResponse
from airbrowser_client.models.browsers_request import BrowsersRequest
from airbrowser_client.models.click_request import ClickRequest
from airbrowser_client.models.console_logs_request import ConsoleLogsRequest
from airbrowser_client.models.cookies_request import CookiesRequest
from airbrowser_client.models.create_browser_request import CreateBrowserRequest
from airbrowser_client.models.create_profile_request import CreateProfileRequest
from airbrowser_client.models.detect_coordinates_request import DetectCoordinatesRequest
from airbrowser_client.models.dialog_request import DialogRequest
from airbrowser_client.models.emulate_request import EmulateRequest
from airbrowser_client.models.error_response import ErrorResponse
from airbrowser_client.models.execute_cdp_request import ExecuteCdpRequest
from airbrowser_client.models.execute_script_request import ExecuteScriptRequest
from airbrowser_client.models.fill_form_request import FillFormRequest
from airbrowser_client.models.generic_response import GenericResponse
from airbrowser_client.models.gui_click_request import GuiClickRequest
from airbrowser_client.models.gui_hover_xy_request import GuiHoverXyRequest
from airbrowser_client.models.gui_press_keys_xy_request import GuiPressKeysXyRequest
from airbrowser_client.models.gui_type_xy_request import GuiTypeXyRequest
from airbrowser_client.models.health_status import HealthStatus
from airbrowser_client.models.history_request import HistoryRequest
from airbrowser_client.models.mouse_request import MouseRequest
from airbrowser_client.models.navigate_browser_request import NavigateBrowserRequest
from airbrowser_client.models.network_logs_request import NetworkLogsRequest
from airbrowser_client.models.performance_request import PerformanceRequest
from airbrowser_client.models.pool_scaled import PoolScaled
from airbrowser_client.models.press_keys_request import PressKeysRequest
from airbrowser_client.models.profile_info import ProfileInfo
from airbrowser_client.models.profile_list_data import ProfileListData
from airbrowser_client.models.profile_list_response import ProfileListResponse
from airbrowser_client.models.profile_response import ProfileResponse
from airbrowser_client.models.resize_request import ResizeRequest
from airbrowser_client.models.scale_data import ScaleData
from airbrowser_client.models.scale_pool import ScalePool
from airbrowser_client.models.scroll_request import ScrollRequest
from airbrowser_client.models.select_request import SelectRequest
from airbrowser_client.models.snapshot_request import SnapshotRequest
from airbrowser_client.models.tabs_request import TabsRequest
from airbrowser_client.models.take_screenshot_request import TakeScreenshotRequest
from airbrowser_client.models.type_text_request import TypeTextRequest
from airbrowser_client.models.upload_file_request import UploadFileRequest
from airbrowser_client.models.wait_element_request import WaitElementRequest

