# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.models.combined_scroll_request import CombinedScrollRequest

class TestCombinedScrollRequest(unittest.TestCase):
    """CombinedScrollRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CombinedScrollRequest:
        """Test CombinedScrollRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CombinedScrollRequest`
        """
        model = CombinedScrollRequest()
        if include_optional:
            return CombinedScrollRequest(
                selector = '',
                by = 'css',
                x = 56,
                y = 56,
                delta_x = 56,
                delta_y = 56,
                behavior = 'smooth'
            )
        else:
            return CombinedScrollRequest(
        )
        """

    def testCombinedScrollRequest(self):
        """Test CombinedScrollRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
