# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.models.wait_element_request import WaitElementRequest

class TestWaitElementRequest(unittest.TestCase):
    """WaitElementRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WaitElementRequest:
        """Test WaitElementRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WaitElementRequest`
        """
        model = WaitElementRequest()
        if include_optional:
            return WaitElementRequest(
                selector = '',
                by = 'css',
                until = 'visible',
                timeout = 56
            )
        else:
            return WaitElementRequest(
                selector = '',
                until = 'visible',
        )
        """

    def testWaitElementRequest(self):
        """Test WaitElementRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
