# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.api.profiles_api import ProfilesApi


class TestProfilesApi(unittest.TestCase):
    """ProfilesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProfilesApi()

    def tearDown(self) -> None:
        pass

    def test_create_profile(self) -> None:
        """Test case for create_profile

        Create a new browser profile
        """
        pass

    def test_delete_profile(self) -> None:
        """Test case for delete_profile

        Delete a browser profile
        """
        pass

    def test_get_profile(self) -> None:
        """Test case for get_profile

        Get profile information
        """
        pass

    def test_list_profiles(self) -> None:
        """Test case for list_profiles

        List all browser profiles
        """
        pass


if __name__ == '__main__':
    unittest.main()
