# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.models.browser_config import BrowserConfig

class TestBrowserConfig(unittest.TestCase):
    """BrowserConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BrowserConfig:
        """Test BrowserConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BrowserConfig`
        """
        model = BrowserConfig()
        if include_optional:
            return BrowserConfig(
                profile_name = 'dev-session',
                proxy = '',
                user_agent = '',
                window_size = [
                    56
                    ],
                disable_gpu = True,
                disable_images = True,
                disable_javascript = True,
                extensions = [
                    ''
                    ],
                custom_args = [
                    ''
                    ]
            )
        else:
            return BrowserConfig(
        )
        """

    def testBrowserConfig(self):
        """Test BrowserConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
